==> replicated-config-render-1.0.1.tgz: package/components/ConfigTestWidget.jsx <==
var request = require('superagent');
var _ = require('lodash');
var classNames = require('classnames');
var React = require('react');

var ConfigTestWidget = React.createClass({
  getInitialState: function() {
    return {
      'resultText': '',
      'success': null,
      'testing': false
    };
  },

  handleTest: function(e) {
    e.preventDefault();

    this.setState({
      'testing': true,
      'resultText': ''
    });

    if (this.pendingRequest) {
      this.pendingRequest.abort();
    }

    var requestData = {
      'command': this.props.testProc.command,
      'timeout': this.props.testProc.timeout || 0,
      'arg_fields': this.getArgs()
    };

    this.pendingRequest = request
      .get('/api/v1/config/test')
      .send(requestData)
      .end(function(err, res) {
        if (err) {
          this.pendingRequest = null;

          var errText;
          if (res) {
            if (res.status === 0) {
              // aborted
              return;
            }
            errText = res.text || err.toString();
          } else {
            errText = err.toString();
          }

          this.setState({
            'testing': false,
            'success': false,
            'resultText': errText
          });
          return;
        }

        this.pendingRequest = null;
        this.setState({
          'testing': false,
          'success': true,
          'resultText': 'Success'
        });
      }.bind(this));
  },

  getArgs: function() {
    var defaultArgs = [];
    _.each(this.props.testProc.arg_fields, _.bind(function(field) {
      _.some(this.props.allItems, function(item) {
        if (item.name === field) {
          if (item.type === 'file') {
            defaultArgs.push({
              field: item.name,
              value: item.data
            });
          } else {
            defaultArgs.push({
              field: item.name,
              value: item.value && item.value.length > 0 ? item.value : item.default
            });
          }
          return true;
        }
        return false;
      });
    }, this));
    return defaultArgs;
  },

  render: function() {
    var iconTesting = null, iconSuccess = null, iconFail = null;
    if (this.state.testing === true) {
      iconTesting = <i className="fa fa-cog fa-spin"></i>
    } else {
      if (this.state.success === true) {
        iconSuccess = <i className="fa fa-check-square"></i>
      }
      if (this.state.success === false) {
        iconFail = <i className="fa fa-times-circle"></i>
      }
    }

    var statusClasses = classNames('test-status', {
      'text-success': !this.state.testing && this.state.success === true,
      'text-danger': !this.state.testing && this.state.success === false
    });

    return (
      <div className="test-widget clearfix">
        <div>
          <span>
            <a href="#" onClick={this.handleTest} className="test-button btn btn-info btn-sm pull-left">
              {_.get(this.props.testProc, 'display_name', 'Test')}
            </a>
          </span>
          <small className={statusClasses}>{iconTesting} {iconSuccess} {iconFail} {this.state.resultText}</small>
        </div>
      </div>
    );
  }
});

module.exports = ConfigTestWidget;

==> replicated-config-render-1.0.5.tgz: package/components/ConfigTestWidget.jsx <==
var request = require('superagent');
var _ = require('lodash');
var classNames = require('classnames');
var React = require('react');

var MockRequest = function(callback) {
  this.timeout = setTimeout(callback, 2000);
};

MockRequest.prototype.abort = function() {
  clearTimeout(this.timeout);
};

var ConfigTestWidget = React.createClass({
  getInitialState: function() {
    return {
      'resultText': '',
      'success': null,
      'testing': false
    };
  },

  handleTest: function(e) {
    e.preventDefault();

    this.setState({
      'testing': true,
      'resultText': ''
    });

    if (this.pendingRequest) {
      this.pendingRequest.abort();
    }

    var requestData = {
      'command': this.props.testProc.command,
      'timeout': this.props.testProc.timeout || 0,
      'arg_fields': this.getArgs()
    };

    if (this.props.testUrl) {
      this.pendingRequest = request
        .get(this.props.testUrl) // '/api/v1/config/test'
        .send(requestData)
        .end(function(err, res) {
          if (err) {
            this.pendingRequest = null;

            var errText;
            if (res) {
              if (res.status === 0) {
                // aborted
                return;
              }
              errText = res.text || err.toString();
            } else {
              errText = err.toString();
            }

            this.setState({
              'testing': false,
              'success': false,
              'resultText': errText
            });
            return;
          }

          this.pendingRequest = null;
          this.setState({
            'testing': false,
            'success': true,
            'resultText': 'Success'
          });
        }.bind(this));
    } else {
      this.pendingRequest = new MockRequest(function() {
        this.setState({
          'testing': false,
          'success': true,
          'resultText': 'Success'
        });
      }.bind(this));
    }
  },

  getArgs: function() {
    var defaultArgs = [];
    _.each(this.props.testProc.arg_fields, _.bind(function(field) {
      _.some(this.props.allItems, function(item) {
        if (item.name === field) {
          if (item.type === 'file') {
            defaultArgs.push({
              field: item.name,
              value: item.data
            });
          } else {
            defaultArgs.push({
              field: item.name,
              value: item.value && item.value.length > 0 ? item.value : item.default
            });
          }
          return true;
        }
        return false;
      });
    }, this));
    return defaultArgs;
  },

  render: function() {
    var iconTesting = null, iconSuccess = null, iconFail = null;
    if (this.state.testing === true) {
      iconTesting = <i className="fa fa-cog fa-spin"></i>;
    } else {
      if (this.state.success === true) {
        iconSuccess = <i className="fa fa-check-square"></i>;
      }
      if (this.state.success === false) {
        iconFail = <i className="fa fa-times-circle"></i>;
      }
    }

    var statusClasses = classNames('test-status', {
      'text-success': !this.state.testing && this.state.success === true,
      'text-danger': !this.state.testing && this.state.success === false
    });

    return (
      <div className="test-widget clearfix">
        <div>
          <span>
            <a href="#" onClick={this.handleTest} className="test-button btn btn-info btn-sm pull-left">
              {_.get(this.props.testProc, 'display_name', 'Test')}
            </a>
          </span>
          <small className={statusClasses}>{iconTesting} {iconSuccess} {iconFail} {this.state.resultText}</small>
        </div>
      </div>
    );
  }
});

module.exports = ConfigTestWidget;
